@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0206';
+our $VERSION = '0.0207';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -169,7 +169,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0206
+version 0.0207
 
 =head1 SYNOPSIS
 
@@ -192,8 +192,8 @@ minus the notes those replaced."
 
 The logic (and music theory) implemented here, can generate some sour
 notes.  This is an approximate composition tool, and not a drop-in
-bass player.  Import rendered MIDI into a DAW and alter things until
-they are suitable.
+bass player.  Import rendered MIDI into a DAW and alter notes until
+they sound suitable.
 
 The chords recognized by this module, are those known to
 L<Music::Chord::Note>.  Please see the source of that module for the
@@ -258,7 +258,9 @@ Default: C<0>
 
 =head2 new
 
+  $bassline = MIDI::Bassline::Walk->new;
   $bassline = MIDI::Bassline::Walk->new(
+      guitar    => $guitar,
       intervals => $intervals,
       octave    => $octave,
       scale     => $scale,
